%%
%% This is file `lettrine-xetex-bidi.def', by Daniel Flipo,
%% as a replacement for Vafa Khalighi's original (outdated) file.
%%
\ProvidesFile{lettrine-xetex-bidi.def}%
  [2024/01/20 v1.0 bidi adaptations for lettrine package for XeTeX engine]
\IfPackageAtLeastTF{lettrine}{2024-01-20}{}%
{\PackageWarning{bidi}{Please upgrade your lettrine package\MessageBreak
                       to version 2.60 or higher}}
\endinput
%%
%% End of file `lettrine-xetex-bidi.def'.
